@@ -2,18 +2,21 @@ from dataclasses import dataclass, field
 from datetime import datetime
 from marshmallow import fields
 import dateutil.parser
-from typing import List,Optional
+from typing import Optional
 from dataclasses_json import dataclass_json
 
 
 @dataclass_json
 @dataclass
 class API:
+    r"""API
+    An Api is representation of a API (a collection of API Endpoints) within the Speakeasy Platform.
+    """
     api_id: str = field(default=None, metadata={'dataclasses_json': { 'field_name': 'api_id' }})
     created_at: datetime = field(default=None, metadata={'dataclasses_json': { 'field_name': 'created_at', 'encoder': datetime.isoformat, 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
     description: str = field(default=None, metadata={'dataclasses_json': { 'field_name': 'description' }})
     matched: Optional[bool] = field(default=None, metadata={'dataclasses_json': { 'field_name': 'matched' }})
-    meta_data: Optional[dict[str, List[str]]] = field(default=None, metadata={'dataclasses_json': { 'field_name': 'meta_data' }})
+    meta_data: Optional[dict[str, list[str]]] = field(default=None, metadata={'dataclasses_json': { 'field_name': 'meta_data' }})
     updated_at: datetime = field(default=None, metadata={'dataclasses_json': { 'field_name': 'updated_at', 'encoder': datetime.isoformat, 'decoder': dateutil.parser.isoparse, 'mm_field': fields.DateTime(format='iso') }})
     version_id: str = field(default=None, metadata={'dataclasses_json': { 'field_name': 'version_id' }})
     workspace_id: str = field(default=None, metadata={'dataclasses_json': { 'field_name': 'workspace_id' }})
