@@ -1,6 +1,6 @@
-import warnings
+__doc__ = """ SDK Documentation: https://docs.speakeasyapi.dev - The Speakeasy Platform Documentation"""
 import requests
-from typing import List,Optional
+from typing import Optional
 from sdk.models import operations, shared
 from . import utils
 
@@ -11,6 +11,7 @@ SERVERS = [
 
 
 class SDK:
+    r"""SDK Documentation: https://docs.speakeasyapi.dev - The Speakeasy Platform Documentation"""
     client = requests.Session()
     server_url = SERVERS[0]
 
@@ -26,13 +27,17 @@ class SDK:
 
     
     def delete_api(self, request: operations.DeleteAPIRequest) -> operations.DeleteAPIResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Delete an Api.
+        Delete a particular version of an Api. The will also delete all associated ApiEndpoints, Metadata, Schemas & Request Logs (if using a Postgres datastore).
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("DELETE", url)
         content_type = r.headers.get("Content-Type")
 
@@ -49,13 +54,17 @@ class SDK:
 
     
     def delete_api_endpoint(self, request: operations.DeleteAPIEndpointRequest) -> operations.DeleteAPIEndpointResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Delete an ApiEndpoint.
+        Delete an ApiEndpoint. This will also delete all associated Request Logs (if using a Postgres datastore).
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/api_endpoints/{apiEndpointID}", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("DELETE", url)
         content_type = r.headers.get("Content-Type")
 
@@ -72,13 +81,16 @@ class SDK:
 
     
     def delete_schema(self, request: operations.DeleteSchemaRequest) -> operations.DeleteSchemaResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Delete a particular schema revision for an Api.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/schema/{revisionID}", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("DELETE", url)
         content_type = r.headers.get("Content-Type")
 
@@ -95,13 +107,16 @@ class SDK:
 
     
     def delete_version_metadata(self, request: operations.DeleteVersionMetadataRequest) -> operations.DeleteVersionMetadataResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Delete metadata for a particular apiID and versionID.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/metadata/{metaKey}/{metaValue}", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("DELETE", url)
         content_type = r.headers.get("Content-Type")
 
@@ -118,13 +133,16 @@ class SDK:
 
     
     def download_schema(self, request: operations.DownloadSchemaRequest) -> operations.DownloadSchemaResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Download the latest schema for a particular apiID.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/schema/download", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -145,13 +163,16 @@ class SDK:
 
     
     def download_schema_revision(self, request: operations.DownloadSchemaRevisionRequest) -> operations.DownloadSchemaRevisionResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Download a particular schema revision for an Api.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/schema/{revisionID}/download", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -172,13 +193,18 @@ class SDK:
 
     
     def find_api_endpoint(self, request: operations.FindAPIEndpointRequest) -> operations.FindAPIEndpointResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Find an ApiEndpoint via its displayName.
+        Find an ApiEndpoint via its displayName (set by operationId from a registered OpenAPI schema).
+        This is useful for finding the ID of an ApiEndpoint to use in the /v1/apis/{apiID}/version/{versionID}/api_endpoints/{apiEndpointID} endpoints.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/api_endpoints/find/{displayName}", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -197,13 +223,18 @@ class SDK:
 
     
     def generate_open_api_spec(self, request: operations.GenerateOpenAPISpecRequest) -> operations.GenerateOpenAPISpecResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Generate an OpenAPI specification for a particular Api.
+        This endpoint will generate any missing operations in any registered OpenAPI document if the operation does not already exist in the document.
+        Returns the original document and the newly generated document allowing a diff to be performed to see what has changed.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/generate/openapi", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -222,13 +253,18 @@ class SDK:
 
     
     def generate_open_api_spec_for_api_endpoint(self, request: operations.GenerateOpenAPISpecForAPIEndpointRequest) -> operations.GenerateOpenAPISpecForAPIEndpointResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Generate an OpenAPI specification for a particular ApiEndpoint.
+        This endpoint will generate a new operation in any registered OpenAPI document if the operation does not already exist in the document.
+        Returns the original document and the newly generated document allowing a diff to be performed to see what has changed.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/api_endpoints/{apiEndpointID}/generate/openapi", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -247,13 +283,17 @@ class SDK:
 
     
     def generate_postman_collection(self, request: operations.GeneratePostmanCollectionRequest) -> operations.GeneratePostmanCollectionResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Generate a Postman collection for a particular Api.
+        Generates a postman collection containing all endpoints for a particular API. Includes variables produced for any path/query/header parameters included in the OpenAPI document.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/generate/postman", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -272,13 +312,17 @@ class SDK:
 
     
     def generate_postman_collection_for_api_endpoint(self, request: operations.GeneratePostmanCollectionForAPIEndpointRequest) -> operations.GeneratePostmanCollectionForAPIEndpointResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Generate a Postman collection for a particular ApiEndpoint.
+        Generates a postman collection that allows the endpoint to be called from postman variables produced for any path/query/header parameters included in the OpenAPI document.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/api_endpoints/{apiEndpointID}/generate/postman", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -297,13 +341,18 @@ class SDK:
 
     
     def generate_request_postman_collection(self, request: operations.GenerateRequestPostmanCollectionRequest) -> operations.GenerateRequestPostmanCollectionResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Generate a Postman collection for a particular request.
+        Generates a Postman collection for a particular request. 
+        Allowing it to be replayed with the same inputs that were captured by the SDK.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/eventlog/{requestID}/generate/postman", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -322,13 +371,16 @@ class SDK:
 
     
     def get_all_api_endpoints(self, request: operations.GetAllAPIEndpointsRequest) -> operations.GetAllAPIEndpointsResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Get all Api endpoints for a particular apiID.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/api_endpoints", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -336,7 +388,7 @@ class SDK:
         
         if r.status_code == 200:
             if utils.match_content_type(content_type, "application/json"):
-                out = utils.unmarshal_json(r.text, Optional[List[shared.APIEndpoint]])
+                out = utils.unmarshal_json(r.text, Optional[list[shared.APIEndpoint]])
                 res.api_endpoints = out
         else:
             if utils.match_content_type(content_type, "application/json"):
@@ -347,15 +399,19 @@ class SDK:
 
     
     def get_all_api_versions(self, request: operations.GetAllAPIVersionsRequest) -> operations.GetAllAPIVersionsResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Get all Api versions for a particular ApiEndpoint.
+        Get all Api versions for a particular ApiEndpoint.
+        Supports filtering the versions based on metadata attributes.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}", request.path_params)
-
+        
         query_params = utils.get_query_params(request.query_params)
-
+        
         client = self.client
-
+        
         r = client.request("GET", url, params=query_params)
         content_type = r.headers.get("Content-Type")
 
@@ -363,7 +419,7 @@ class SDK:
         
         if r.status_code == 200:
             if utils.match_content_type(content_type, "application/json"):
-                out = utils.unmarshal_json(r.text, Optional[List[shared.API]])
+                out = utils.unmarshal_json(r.text, Optional[list[shared.API]])
                 res.apis = out
         else:
             if utils.match_content_type(content_type, "application/json"):
@@ -374,13 +430,16 @@ class SDK:
 
     
     def get_all_for_version_api_endpoints(self, request: operations.GetAllForVersionAPIEndpointsRequest) -> operations.GetAllForVersionAPIEndpointsResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Get all ApiEndpoints for a particular apiID and versionID.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/api_endpoints", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -388,7 +447,7 @@ class SDK:
         
         if r.status_code == 200:
             if utils.match_content_type(content_type, "application/json"):
-                out = utils.unmarshal_json(r.text, Optional[List[shared.APIEndpoint]])
+                out = utils.unmarshal_json(r.text, Optional[list[shared.APIEndpoint]])
                 res.api_endpoints = out
         else:
             if utils.match_content_type(content_type, "application/json"):
@@ -399,13 +458,16 @@ class SDK:
 
     
     def get_api_endpoint(self, request: operations.GetAPIEndpointRequest) -> operations.GetAPIEndpointResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Get an ApiEndpoint.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/api_endpoints/{apiEndpointID}", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -424,15 +486,19 @@ class SDK:
 
     
     def get_apis(self, request: operations.GetApisRequest) -> operations.GetApisResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Get a list of Apis for a given workspace
+        Get a list of all Apis and their versions for a given workspace.
+        Supports filtering the APIs based on metadata attributes.
+        """
+        
         base_url = self.server_url
+        
         url = base_url.removesuffix("/") + "/v1/apis"
-
+        
         query_params = utils.get_query_params(request.query_params)
-
+        
         client = self.client
-
+        
         r = client.request("GET", url, params=query_params)
         content_type = r.headers.get("Content-Type")
 
@@ -440,7 +506,7 @@ class SDK:
         
         if r.status_code == 200:
             if utils.match_content_type(content_type, "application/json"):
-                out = utils.unmarshal_json(r.text, Optional[List[shared.API]])
+                out = utils.unmarshal_json(r.text, Optional[list[shared.API]])
                 res.apis = out
         else:
             if utils.match_content_type(content_type, "application/json"):
@@ -451,15 +517,19 @@ class SDK:
 
     
     def get_embed_access_token(self, request: operations.GetEmbedAccessTokenRequest) -> operations.GetEmbedAccessTokenResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Get an embed access token for the current workspace.
+        Returns an embed access token for the current workspace. This can be used to authenticate access to externally embedded content.
+        Filters can be applied allowing views to be filtered to things like particular customerIds.
+        """
+        
         base_url = self.server_url
+        
         url = base_url.removesuffix("/") + "/v1/workspace/embed-access-token"
-
+        
         query_params = utils.get_query_params(request.query_params)
-
+        
         client = self.client
-
+        
         r = client.request("GET", url, params=query_params)
         content_type = r.headers.get("Content-Type")
 
@@ -478,13 +548,16 @@ class SDK:
 
     
     def get_request_from_event_log(self, request: operations.GetRequestFromEventLogRequest) -> operations.GetRequestFromEventLogResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Get information about a particular request.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/eventlog/{requestID}", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -503,13 +576,18 @@ class SDK:
 
     
     def get_schema(self, request: operations.GetSchemaRequest) -> operations.GetSchemaResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Get information about the latest schema.
+        Returns information about the last uploaded schema for a particular API version. 
+        This won't include the schema itself, that can be retrieved via the downloadSchema operation.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/schema", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -528,13 +606,16 @@ class SDK:
 
     
     def get_schema_diff(self, request: operations.GetSchemaDiffRequest) -> operations.GetSchemaDiffResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Get a diff of two schema revisions for an Api.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/schema/{baseRevisionID}/diff/{targetRevisionID}", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -553,13 +634,18 @@ class SDK:
 
     
     def get_schema_revision(self, request: operations.GetSchemaRevisionRequest) -> operations.GetSchemaRevisionResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Get information about a particular schema revision for an Api.
+        Returns information about the last uploaded schema for a particular schema revision. 
+        This won't include the schema itself, that can be retrieved via the downloadSchema operation.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/schema/{revisionID}", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -578,13 +664,18 @@ class SDK:
 
     
     def get_schemas(self, request: operations.GetSchemasRequest) -> operations.GetSchemasResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Get information about all schemas associated with a particular apiID.
+        Returns information the schemas associated with a particular apiID. 
+        This won't include the schemas themselves, they can be retrieved via the downloadSchema operation.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/schemas", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -592,7 +683,7 @@ class SDK:
         
         if r.status_code == 200:
             if utils.match_content_type(content_type, "application/json"):
-                out = utils.unmarshal_json(r.text, Optional[List[shared.Schema]])
+                out = utils.unmarshal_json(r.text, Optional[list[shared.Schema]])
                 res.schemata = out
         else:
             if utils.match_content_type(content_type, "application/json"):
@@ -603,13 +694,16 @@ class SDK:
 
     
     def get_valid_embed_access_tokens(self) -> operations.GetValidEmbedAccessTokensResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Get all valid embed access tokens for the current workspace.
+        """
+        
         base_url = self.server_url
+        
         url = base_url.removesuffix("/") + "/v1/workspace/embed-access-tokens/valid"
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -617,7 +711,7 @@ class SDK:
         
         if r.status_code == 200:
             if utils.match_content_type(content_type, "application/json"):
-                out = utils.unmarshal_json(r.text, Optional[List[shared.EmbedToken]])
+                out = utils.unmarshal_json(r.text, Optional[list[shared.EmbedToken]])
                 res.embed_tokens = out
         else:
             if utils.match_content_type(content_type, "application/json"):
@@ -628,13 +722,16 @@ class SDK:
 
     
     def get_version_metadata(self, request: operations.GetVersionMetadataRequest) -> operations.GetVersionMetadataResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Get all metadata for a particular apiID and versionID.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/metadata", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("GET", url)
         content_type = r.headers.get("Content-Type")
 
@@ -642,7 +739,7 @@ class SDK:
         
         if r.status_code == 200:
             if utils.match_content_type(content_type, "application/json"):
-                out = utils.unmarshal_json(r.text, Optional[List[shared.VersionMetadata]])
+                out = utils.unmarshal_json(r.text, Optional[list[shared.VersionMetadata]])
                 res.version_metadata = out
         else:
             if utils.match_content_type(content_type, "application/json"):
@@ -653,22 +750,22 @@ class SDK:
 
     
     def insert_version_metadata(self, request: operations.InsertVersionMetadataRequest) -> operations.InsertVersionMetadataResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Insert metadata for a particular apiID and versionID.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/metadata", request.path_params)
-
+        
         headers = {}
-
         req_content_type, data, form = utils.serialize_request_body(request)
         if req_content_type != "multipart/form-data" and req_content_type != "multipart/mixed":
             headers["content-type"] = req_content_type
-
         if data is None and form is None:
            raise Exception('request body is required')
-
+        
         client = self.client
-
+        
         r = client.request("POST", url, data=data, files=form, headers=headers)
         content_type = r.headers.get("Content-Type")
 
@@ -687,15 +784,19 @@ class SDK:
 
     
     def query_event_log(self, request: operations.QueryEventLogRequest) -> operations.QueryEventLogResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Query the event log to retrieve a list of requests.
+        Supports retrieving a list of request captured by the SDK for this workspace.
+        Allows the filtering of requests on a number of criteria such as ApiID, VersionID, Path, Method, etc.
+        """
+        
         base_url = self.server_url
+        
         url = base_url.removesuffix("/") + "/v1/eventlog/query"
-
+        
         query_params = utils.get_query_params(request.query_params)
-
+        
         client = self.client
-
+        
         r = client.request("GET", url, params=query_params)
         content_type = r.headers.get("Content-Type")
 
@@ -703,7 +804,7 @@ class SDK:
         
         if r.status_code == 200:
             if utils.match_content_type(content_type, "application/json"):
-                out = utils.unmarshal_json(r.text, Optional[List[shared.BoundedRequest]])
+                out = utils.unmarshal_json(r.text, Optional[list[shared.BoundedRequest]])
                 res.bounded_requests = out
         else:
             if utils.match_content_type(content_type, "application/json"):
@@ -714,22 +815,24 @@ class SDK:
 
     
     def register_schema(self, request: operations.RegisterSchemaRequest) -> operations.RegisterSchemaResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Register a schema.
+        Allows uploading a schema for a particular API version.
+        This will be used to populate ApiEndpoints and used as a base for any schema generation if present.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/schema", request.path_params)
-
+        
         headers = {}
-
         req_content_type, data, form = utils.serialize_request_body(request)
         if req_content_type != "multipart/form-data" and req_content_type != "multipart/mixed":
             headers["content-type"] = req_content_type
-
         if data is None and form is None:
            raise Exception('request body is required')
-
+        
         client = self.client
-
+        
         r = client.request("POST", url, data=data, files=form, headers=headers)
         content_type = r.headers.get("Content-Type")
 
@@ -746,13 +849,16 @@ class SDK:
 
     
     def revoke_embed_access_token(self, request: operations.RevokeEmbedAccessTokenRequest) -> operations.RevokeEmbedAccessTokenResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Revoke an embed access EmbedToken.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/workspace/embed-access-tokens/{tokenID}", request.path_params)
-
+        
+        
         client = self.client
-
+        
         r = client.request("DELETE", url)
         content_type = r.headers.get("Content-Type")
 
@@ -769,22 +875,24 @@ class SDK:
 
     
     def upsert_api(self, request: operations.UpsertAPIRequest) -> operations.UpsertAPIResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Upsert an Api
+        Upsert an Api. If the Api does not exist, it will be created.
+        If the Api exists, it will be updated.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}", request.path_params)
-
+        
         headers = {}
-
         req_content_type, data, form = utils.serialize_request_body(request)
         if req_content_type != "multipart/form-data" and req_content_type != "multipart/mixed":
             headers["content-type"] = req_content_type
-
         if data is None and form is None:
            raise Exception('request body is required')
-
+        
         client = self.client
-
+        
         r = client.request("PUT", url, data=data, files=form, headers=headers)
         content_type = r.headers.get("Content-Type")
 
@@ -803,22 +911,23 @@ class SDK:
 
     
     def upsert_api_endpoint(self, request: operations.UpsertAPIEndpointRequest) -> operations.UpsertAPIEndpointResponse:
-        warnings.simplefilter("ignore")
-
+        r"""Upsert an ApiEndpoint.
+        Upsert an ApiEndpoint. If the ApiEndpoint does not exist it will be created, otherwise it will be updated.
+        """
+        
         base_url = self.server_url
+        
         url = utils.generate_url(base_url, "/v1/apis/{apiID}/version/{versionID}/api_endpoints/{apiEndpointID}", request.path_params)
-
+        
         headers = {}
-
         req_content_type, data, form = utils.serialize_request_body(request)
         if req_content_type != "multipart/form-data" and req_content_type != "multipart/mixed":
             headers["content-type"] = req_content_type
-
         if data is None and form is None:
            raise Exception('request body is required')
-
+        
         client = self.client
-
+        
         r = client.request("PUT", url, data=data, files=form, headers=headers)
         content_type = r.headers.get("Content-Type")
 
